==> ejc-proother-api-3.0.0-20220322.024816-11-sources.jar: com/ejianc/business/proother/vo/ContractClauseVO.java <==
package com.ejianc.business.proother.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 分包合同条款
 * 
 * @author generator
 * 
 */
public class ContractClauseVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    /**
     * 合同条款名称Id
     */
    private Long clauseNameId;

    /**
     * 合同条款名称
     */
    private String clauseName;

    /**
     * 合同条款内容
     */
    private String clauseContent;

    /**
     * 所属合同Id
     */
    private Long contractId;

    /**
     * 变更主键
     */
    private Long changeId;

    /**
     * 变更子表主键
     */
    private Long changeBid;


    public Long getClauseNameId() {
        return clauseNameId;
    }

    @ReferDeserialTransfer
    public void setClauseNameId(Long clauseNameId) {
        this.clauseNameId = clauseNameId;
    }

    public String getClauseName() {
        return clauseName;
    }

    public void setClauseName(String clauseName) {
        this.clauseName = clauseName;
    }

    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }
}

==> ejc-proother-api-3.0.0-20220521.015449-86-sources.jar: com/ejianc/business/proother/vo/ContractClauseVO.java <==
package com.ejianc.business.proother.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 分包合同条款
 * 
 * @author generator
 * 
 */
public class ContractClauseVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    /**
     * 合同条款名称Id
     */
    private Long clauseNameId;

    /**
     * 合同条款名称
     */
    private String clauseName;

    /**
     * 合同条款内容
     */
    private String clauseContent;

    /**
     * 是否必填：1-是，0否
     */
    private Integer necessaryStatus;

    /**
     * 所属合同Id
     */
    private Long contractId;

    /**
     * 变更主键
     */
    private Long changeId;

    /**
     * 变更子表主键
     */
    private Long changeBid;

    public Integer getNecessaryStatus() {
        return necessaryStatus;
    }

    public void setNecessaryStatus(Integer necessaryStatus) {
        this.necessaryStatus = necessaryStatus;
    }

    public Long getClauseNameId() {
        return clauseNameId;
    }

    @ReferDeserialTransfer
    public void setClauseNameId(Long clauseNameId) {
        this.clauseNameId = clauseNameId;
    }

    public String getClauseName() {
        return clauseName;
    }

    public void setClauseName(String clauseName) {
        this.clauseName = clauseName;
    }

    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }
}
